# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/api/model.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from clarifai.rest.grpc.proto.clarifai.api import common_pb2 as proto_dot_clarifai_dot_api_dot_common__pb2
from clarifai.rest.grpc.proto.clarifai.api import data_pb2 as proto_dot_clarifai_dot_api_dot_data__pb2
from clarifai.rest.grpc.proto.clarifai.api import model_version_pb2 as proto_dot_clarifai_dot_api_dot_model__version__pb2
from clarifai.rest.grpc.proto.clarifai.api import concept_pb2 as proto_dot_clarifai_dot_api_dot_concept__pb2
from clarifai.rest.grpc.proto.clarifai.api.status import status_pb2 as proto_dot_clarifai_dot_api_dot_status_dot_status__pb2
from clarifai.rest.grpc.proto.clarifai.api.utils import extensions_pb2 as proto_dot_clarifai_dot_api_dot_utils_dot_extensions__pb2
from clarifai.rest.grpc.proto.clarifai.utils.pagination import pagination_pb2 as proto_dot_clarifai_dot_utils_dot_pagination_dot_pagination__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/api/model.proto',
  package='clarifai.api',
  syntax='proto3',
  serialized_pb=_b('\n\x1eproto/clarifai/api/model.proto\x12\x0c\x63larifai.api\x1a\x1fproto/clarifai/api/common.proto\x1a\x1dproto/clarifai/api/data.proto\x1a&proto/clarifai/api/model_version.proto\x1a proto/clarifai/api/concept.proto\x1a&proto/clarifai/api/status/status.proto\x1a)proto/clarifai/api/utils/extensions.proto\x1a\x30proto/clarifai/utils/pagination/pagination.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xdf\x01\n\x05Model\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x06\x61pp_id\x18\x04 \x01(\tB\x04\x80\xb5\x18\x01\x12-\n\x0boutput_info\x18\x05 \x01(\x0b\x32\x18.clarifai.api.OutputInfo\x12\x31\n\rmodel_version\x18\x06 \x01(\x0b\x32\x1a.clarifai.api.ModelVersion\x12\x14\n\x0c\x64isplay_name\x18\x07 \x01(\t\"\x92\x01\n\nOutputInfo\x12 \n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x12.clarifai.api.Data\x12\x31\n\routput_config\x18\x02 \x01(\x0b\x32\x1a.clarifai.api.OutputConfig\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x10\n\x08type_ext\x18\x05 \x01(\t\"\x99\x02\n\x0cOutputConfig\x12)\n\x1b\x63oncepts_mutually_exclusive\x18\x01 \x01(\x08\x42\x04\x80\xb5\x18\x01\x12 \n\x12\x63losed_environment\x18\x02 \x01(\x08\x42\x04\x80\xb5\x18\x01\x12\x1d\n\x11\x65xisting_model_id\x18\x03 \x01(\tB\x02\x18\x01\x12\x10\n\x08language\x18\x04 \x01(\t\x12\x18\n\x10hyper_parameters\x18\x05 \x01(\t\x12\x14\n\x0cmax_concepts\x18\x06 \x01(\r\x12\x11\n\tmin_value\x18\x07 \x01(\x02\x12.\n\x0fselect_concepts\x18\x08 \x03(\x0b\x32\x15.clarifai.api.Concept\x12\x18\n\x10training_timeout\x18\t \x01(\r\"(\n\nModelQuery\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"h\n\x0fGetModelRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x12\n\nversion_id\x18\x03 \x01(\t\"r\n\x19GetModelOutputInfoRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x12\n\nversion_id\x18\x03 \x01(\t\"q\n\x11ListModelsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x0c\n\x04page\x18\x02 \x01(\r\x12\x10\n\x08per_page\x18\x03 \x01(\r\x12\x0b\n\x03ids\x18\x04 \x03(\t\"\x91\x01\n\x11PostModelsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12&\n\x05model\x18\x02 \x01(\x0b\x32\x13.clarifai.api.ModelB\x02\x18\x01\x12#\n\x06models\x18\x03 \x03(\x0b\x32\x13.clarifai.api.Model\"z\n\x12PatchModelsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12#\n\x06models\x18\x02 \x03(\x0b\x32\x13.clarifai.api.Model\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\"W\n\x12\x44\x65leteModelRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\"g\n\x13\x44\x65leteModelsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x0b\n\x03ids\x18\x02 \x03(\t\x12\x12\n\ndelete_all\x18\x03 \x01(\x08\"\x9c\x01\n\x19PostModelsSearchesRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12-\n\x0bmodel_query\x18\x02 \x01(\x0b\x32\x18.clarifai.api.ModelQuery\x12\x1f\n\npagination\x18\x03 \x01(\x0b\x32\x0b.Pagination\"f\n\x13SingleModelResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12\"\n\x05model\x18\x02 \x01(\x0b\x32\x13.clarifai.api.Model\"l\n\x12MultiModelResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12)\n\x06models\x18\x02 \x03(\x0b\x32\x13.clarifai.api.ModelB\x04\x80\xb5\x18\x01\"\x96\x01\n\x19SingleModelWeightResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12\"\n\x05model\x18\x02 \x01(\x0b\x32\x13.clarifai.api.Model\x12\x0c\n\x04\x63t64\x18\x03 \x01(\x0c\x12\x1a\n\x12proto_download_url\x18\x04 \x01(\tB$Z\x03\x61pi\xa2\x02\x04\x43\x41IP\xc2\x02\x01_\xca\x02\x11\x43larifai\\Internalb\x06proto3')
  ,
  dependencies=[proto_dot_clarifai_dot_api_dot_common__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_data__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_model__version__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_concept__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_utils_dot_extensions__pb2.DESCRIPTOR,proto_dot_clarifai_dot_utils_dot_pagination_dot_pagination__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_MODEL = _descriptor.Descriptor(
  name='Model',
  full_name='clarifai.api.Model',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='clarifai.api.Model.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='clarifai.api.Model.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='clarifai.api.Model.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='clarifai.api.Model.app_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_info', full_name='clarifai.api.Model.output_info', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_version', full_name='clarifai.api.Model.model_version', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='clarifai.api.Model.display_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=608,
)


_OUTPUTINFO = _descriptor.Descriptor(
  name='OutputInfo',
  full_name='clarifai.api.OutputInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='clarifai.api.OutputInfo.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_config', full_name='clarifai.api.OutputInfo.output_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='clarifai.api.OutputInfo.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='clarifai.api.OutputInfo.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_ext', full_name='clarifai.api.OutputInfo.type_ext', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=611,
  serialized_end=757,
)


_OUTPUTCONFIG = _descriptor.Descriptor(
  name='OutputConfig',
  full_name='clarifai.api.OutputConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='concepts_mutually_exclusive', full_name='clarifai.api.OutputConfig.concepts_mutually_exclusive', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='closed_environment', full_name='clarifai.api.OutputConfig.closed_environment', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='existing_model_id', full_name='clarifai.api.OutputConfig.existing_model_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='clarifai.api.OutputConfig.language', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hyper_parameters', full_name='clarifai.api.OutputConfig.hyper_parameters', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_concepts', full_name='clarifai.api.OutputConfig.max_concepts', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_value', full_name='clarifai.api.OutputConfig.min_value', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='select_concepts', full_name='clarifai.api.OutputConfig.select_concepts', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='training_timeout', full_name='clarifai.api.OutputConfig.training_timeout', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=760,
  serialized_end=1041,
)


_MODELQUERY = _descriptor.Descriptor(
  name='ModelQuery',
  full_name='clarifai.api.ModelQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='clarifai.api.ModelQuery.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='clarifai.api.ModelQuery.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1043,
  serialized_end=1083,
)


_GETMODELREQUEST = _descriptor.Descriptor(
  name='GetModelRequest',
  full_name='clarifai.api.GetModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.GetModelRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.GetModelRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_id', full_name='clarifai.api.GetModelRequest.version_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1085,
  serialized_end=1189,
)


_GETMODELOUTPUTINFOREQUEST = _descriptor.Descriptor(
  name='GetModelOutputInfoRequest',
  full_name='clarifai.api.GetModelOutputInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.GetModelOutputInfoRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.GetModelOutputInfoRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_id', full_name='clarifai.api.GetModelOutputInfoRequest.version_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1191,
  serialized_end=1305,
)


_LISTMODELSREQUEST = _descriptor.Descriptor(
  name='ListModelsRequest',
  full_name='clarifai.api.ListModelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.ListModelsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='clarifai.api.ListModelsRequest.page', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_page', full_name='clarifai.api.ListModelsRequest.per_page', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ids', full_name='clarifai.api.ListModelsRequest.ids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1307,
  serialized_end=1420,
)


_POSTMODELSREQUEST = _descriptor.Descriptor(
  name='PostModelsRequest',
  full_name='clarifai.api.PostModelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PostModelsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='clarifai.api.PostModelsRequest.model', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='models', full_name='clarifai.api.PostModelsRequest.models', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1423,
  serialized_end=1568,
)


_PATCHMODELSREQUEST = _descriptor.Descriptor(
  name='PatchModelsRequest',
  full_name='clarifai.api.PatchModelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PatchModelsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='models', full_name='clarifai.api.PatchModelsRequest.models', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='clarifai.api.PatchModelsRequest.action', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1570,
  serialized_end=1692,
)


_DELETEMODELREQUEST = _descriptor.Descriptor(
  name='DeleteModelRequest',
  full_name='clarifai.api.DeleteModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.DeleteModelRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.DeleteModelRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1694,
  serialized_end=1781,
)


_DELETEMODELSREQUEST = _descriptor.Descriptor(
  name='DeleteModelsRequest',
  full_name='clarifai.api.DeleteModelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.DeleteModelsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ids', full_name='clarifai.api.DeleteModelsRequest.ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_all', full_name='clarifai.api.DeleteModelsRequest.delete_all', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1783,
  serialized_end=1886,
)


_POSTMODELSSEARCHESREQUEST = _descriptor.Descriptor(
  name='PostModelsSearchesRequest',
  full_name='clarifai.api.PostModelsSearchesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PostModelsSearchesRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_query', full_name='clarifai.api.PostModelsSearchesRequest.model_query', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='clarifai.api.PostModelsSearchesRequest.pagination', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1889,
  serialized_end=2045,
)


_SINGLEMODELRESPONSE = _descriptor.Descriptor(
  name='SingleModelResponse',
  full_name='clarifai.api.SingleModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.SingleModelResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='clarifai.api.SingleModelResponse.model', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2047,
  serialized_end=2149,
)


_MULTIMODELRESPONSE = _descriptor.Descriptor(
  name='MultiModelResponse',
  full_name='clarifai.api.MultiModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.MultiModelResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='models', full_name='clarifai.api.MultiModelResponse.models', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2151,
  serialized_end=2259,
)


_SINGLEMODELWEIGHTRESPONSE = _descriptor.Descriptor(
  name='SingleModelWeightResponse',
  full_name='clarifai.api.SingleModelWeightResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.SingleModelWeightResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='clarifai.api.SingleModelWeightResponse.model', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ct64', full_name='clarifai.api.SingleModelWeightResponse.ct64', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proto_download_url', full_name='clarifai.api.SingleModelWeightResponse.proto_download_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2262,
  serialized_end=2412,
)

_MODEL.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MODEL.fields_by_name['output_info'].message_type = _OUTPUTINFO
_MODEL.fields_by_name['model_version'].message_type = proto_dot_clarifai_dot_api_dot_model__version__pb2._MODELVERSION
_OUTPUTINFO.fields_by_name['data'].message_type = proto_dot_clarifai_dot_api_dot_data__pb2._DATA
_OUTPUTINFO.fields_by_name['output_config'].message_type = _OUTPUTCONFIG
_OUTPUTCONFIG.fields_by_name['select_concepts'].message_type = proto_dot_clarifai_dot_api_dot_concept__pb2._CONCEPT
_GETMODELREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_GETMODELOUTPUTINFOREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_LISTMODELSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTMODELSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTMODELSREQUEST.fields_by_name['model'].message_type = _MODEL
_POSTMODELSREQUEST.fields_by_name['models'].message_type = _MODEL
_PATCHMODELSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_PATCHMODELSREQUEST.fields_by_name['models'].message_type = _MODEL
_DELETEMODELREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_DELETEMODELSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTMODELSSEARCHESREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTMODELSSEARCHESREQUEST.fields_by_name['model_query'].message_type = _MODELQUERY
_POSTMODELSSEARCHESREQUEST.fields_by_name['pagination'].message_type = proto_dot_clarifai_dot_utils_dot_pagination_dot_pagination__pb2._PAGINATION
_SINGLEMODELRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_SINGLEMODELRESPONSE.fields_by_name['model'].message_type = _MODEL
_MULTIMODELRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_MULTIMODELRESPONSE.fields_by_name['models'].message_type = _MODEL
_SINGLEMODELWEIGHTRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_SINGLEMODELWEIGHTRESPONSE.fields_by_name['model'].message_type = _MODEL
DESCRIPTOR.message_types_by_name['Model'] = _MODEL
DESCRIPTOR.message_types_by_name['OutputInfo'] = _OUTPUTINFO
DESCRIPTOR.message_types_by_name['OutputConfig'] = _OUTPUTCONFIG
DESCRIPTOR.message_types_by_name['ModelQuery'] = _MODELQUERY
DESCRIPTOR.message_types_by_name['GetModelRequest'] = _GETMODELREQUEST
DESCRIPTOR.message_types_by_name['GetModelOutputInfoRequest'] = _GETMODELOUTPUTINFOREQUEST
DESCRIPTOR.message_types_by_name['ListModelsRequest'] = _LISTMODELSREQUEST
DESCRIPTOR.message_types_by_name['PostModelsRequest'] = _POSTMODELSREQUEST
DESCRIPTOR.message_types_by_name['PatchModelsRequest'] = _PATCHMODELSREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelRequest'] = _DELETEMODELREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelsRequest'] = _DELETEMODELSREQUEST
DESCRIPTOR.message_types_by_name['PostModelsSearchesRequest'] = _POSTMODELSSEARCHESREQUEST
DESCRIPTOR.message_types_by_name['SingleModelResponse'] = _SINGLEMODELRESPONSE
DESCRIPTOR.message_types_by_name['MultiModelResponse'] = _MULTIMODELRESPONSE
DESCRIPTOR.message_types_by_name['SingleModelWeightResponse'] = _SINGLEMODELWEIGHTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Model = _reflection.GeneratedProtocolMessageType('Model', (_message.Message,), dict(
  DESCRIPTOR = _MODEL,
  __module__ = 'proto.clarifai.api.model_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.Model)
  ))
_sym_db.RegisterMessage(Model)

OutputInfo = _reflection.GeneratedProtocolMessageType('OutputInfo', (_message.Message,), dict(
  DESCRIPTOR = _OUTPUTINFO,
  __module__ = 'proto.clarifai.api.model_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.OutputInfo)
  ))
_sym_db.RegisterMessage(OutputInfo)

OutputConfig = _reflection.GeneratedProtocolMessageType('OutputConfig', (_message.Message,), dict(
  DESCRIPTOR = _OUTPUTCONFIG,
  __module__ = 'proto.clarifai.api.model_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.OutputConfig)
  ))
_sym_db.RegisterMessage(OutputConfig)

ModelQuery = _reflection.GeneratedProtocolMessageType('ModelQuery', (_message.Message,), dict(
  DESCRIPTOR = _MODELQUERY,
  __module__ = 'proto.clarifai.api.model_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ModelQuery)
  ))
_sym_db.RegisterMessage(ModelQuery)

GetModelRequest = _reflection.GeneratedProtocolMessageType('GetModelRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETMODELREQUEST,
  __module__ = 'proto.clarifai.api.model_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetModelRequest)
  ))
_sym_db.RegisterMessage(GetModelRequest)

GetModelOutputInfoRequest = _reflection.GeneratedProtocolMessageType('GetModelOutputInfoRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETMODELOUTPUTINFOREQUEST,
  __module__ = 'proto.clarifai.api.model_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetModelOutputInfoRequest)
  ))
_sym_db.RegisterMessage(GetModelOutputInfoRequest)

ListModelsRequest = _reflection.GeneratedProtocolMessageType('ListModelsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTMODELSREQUEST,
  __module__ = 'proto.clarifai.api.model_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ListModelsRequest)
  ))
_sym_db.RegisterMessage(ListModelsRequest)

PostModelsRequest = _reflection.GeneratedProtocolMessageType('PostModelsRequest', (_message.Message,), dict(
  DESCRIPTOR = _POSTMODELSREQUEST,
  __module__ = 'proto.clarifai.api.model_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PostModelsRequest)
  ))
_sym_db.RegisterMessage(PostModelsRequest)

PatchModelsRequest = _reflection.GeneratedProtocolMessageType('PatchModelsRequest', (_message.Message,), dict(
  DESCRIPTOR = _PATCHMODELSREQUEST,
  __module__ = 'proto.clarifai.api.model_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PatchModelsRequest)
  ))
_sym_db.RegisterMessage(PatchModelsRequest)

DeleteModelRequest = _reflection.GeneratedProtocolMessageType('DeleteModelRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEMODELREQUEST,
  __module__ = 'proto.clarifai.api.model_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.DeleteModelRequest)
  ))
_sym_db.RegisterMessage(DeleteModelRequest)

DeleteModelsRequest = _reflection.GeneratedProtocolMessageType('DeleteModelsRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEMODELSREQUEST,
  __module__ = 'proto.clarifai.api.model_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.DeleteModelsRequest)
  ))
_sym_db.RegisterMessage(DeleteModelsRequest)

PostModelsSearchesRequest = _reflection.GeneratedProtocolMessageType('PostModelsSearchesRequest', (_message.Message,), dict(
  DESCRIPTOR = _POSTMODELSSEARCHESREQUEST,
  __module__ = 'proto.clarifai.api.model_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PostModelsSearchesRequest)
  ))
_sym_db.RegisterMessage(PostModelsSearchesRequest)

SingleModelResponse = _reflection.GeneratedProtocolMessageType('SingleModelResponse', (_message.Message,), dict(
  DESCRIPTOR = _SINGLEMODELRESPONSE,
  __module__ = 'proto.clarifai.api.model_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.SingleModelResponse)
  ))
_sym_db.RegisterMessage(SingleModelResponse)

MultiModelResponse = _reflection.GeneratedProtocolMessageType('MultiModelResponse', (_message.Message,), dict(
  DESCRIPTOR = _MULTIMODELRESPONSE,
  __module__ = 'proto.clarifai.api.model_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.MultiModelResponse)
  ))
_sym_db.RegisterMessage(MultiModelResponse)

SingleModelWeightResponse = _reflection.GeneratedProtocolMessageType('SingleModelWeightResponse', (_message.Message,), dict(
  DESCRIPTOR = _SINGLEMODELWEIGHTRESPONSE,
  __module__ = 'proto.clarifai.api.model_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.SingleModelWeightResponse)
  ))
_sym_db.RegisterMessage(SingleModelWeightResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\003api\242\002\004CAIP\302\002\001_\312\002\021Clarifai\\Internal'))
_MODEL.fields_by_name['app_id'].has_options = True
_MODEL.fields_by_name['app_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
_OUTPUTCONFIG.fields_by_name['concepts_mutually_exclusive'].has_options = True
_OUTPUTCONFIG.fields_by_name['concepts_mutually_exclusive']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
_OUTPUTCONFIG.fields_by_name['closed_environment'].has_options = True
_OUTPUTCONFIG.fields_by_name['closed_environment']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
_OUTPUTCONFIG.fields_by_name['existing_model_id'].has_options = True
_OUTPUTCONFIG.fields_by_name['existing_model_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_POSTMODELSREQUEST.fields_by_name['model'].has_options = True
_POSTMODELSREQUEST.fields_by_name['model']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_MULTIMODELRESPONSE.fields_by_name['models'].has_options = True
_MULTIMODELRESPONSE.fields_by_name['models']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
# @@protoc_insertion_point(module_scope)



import logging
import uuid

from clarifai.rest import ClarifaiApp

urls = [
    "https://samples.clarifai.com/metro-north.jpg",
    "https://samples.clarifai.com/wedding.jpg",
    "https://samples.clarifai.com/facebook.png",
    "https://samples.clarifai.com/dog.tiff",
    "https://samples.clarifai.com/penguin.bmp",
]


def main():
  logger = logging.getLogger('clarifai')
  logger.handlers = []
  logger.addHandler(logging.StreamHandler())
  logger.setLevel(logging.INFO)

  app = ClarifaiApp()

  app.inputs.delete_all()
  app.models.delete_all()

  app.wait_until_inputs_delete_finish()
  app.wait_until_models_delete_finish()

  app.inputs.create_image_from_url(
      urls[0], concepts=['train', 'railway'], allow_duplicate_url=True)
  app.inputs.create_image_from_url(urls[3], concepts=['dog', 'animal'], allow_duplicate_url=True)

  model_id = uuid.uuid4().hex

  model1 = app.models.create(model_id=model_id, concepts=['train', 'railway', 'dog', 'animal'])
  model = model1.train(timeout=240)

  if model.model_status_code != 21100:
    logger.error('Model not trained in 240 seconds with 2 inputs. Test could not continue.')
    exit(2)


if __name__ == '__main__':
  main()



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from clarifai.rest.grpc.proto.clarifai.api import code_pb2 as proto_dot_clarifai_dot_api_dot_code__pb2
from clarifai.rest.grpc.proto.clarifai.api import concept_graph_pb2 as proto_dot_clarifai_dot_api_dot_concept__graph__pb2
from clarifai.rest.grpc.proto.clarifai.api import concept_language_pb2 as proto_dot_clarifai_dot_api_dot_concept__language__pb2
from clarifai.rest.grpc.proto.clarifai.api import concept_pb2 as proto_dot_clarifai_dot_api_dot_concept__pb2
from clarifai.rest.grpc.proto.clarifai.api import concept_reference_pb2 as proto_dot_clarifai_dot_api_dot_concept__reference__pb2
from clarifai.rest.grpc.proto.clarifai.api import endpoint_pb2 as proto_dot_clarifai_dot_api_dot_endpoint__pb2
from clarifai.rest.grpc.proto.clarifai.api import healthz_pb2 as proto_dot_clarifai_dot_api_dot_healthz__pb2
from clarifai.rest.grpc.proto.clarifai.api import input_pb2 as proto_dot_clarifai_dot_api_dot_input__pb2
from clarifai.rest.grpc.proto.clarifai.api import model_pb2 as proto_dot_clarifai_dot_api_dot_model__pb2
from clarifai.rest.grpc.proto.clarifai.api import model_version_pb2 as proto_dot_clarifai_dot_api_dot_model__version__pb2
from clarifai.rest.grpc.proto.clarifai.api import output_pb2 as proto_dot_clarifai_dot_api_dot_output__pb2
from clarifai.rest.grpc.proto.clarifai.api import search_pb2 as proto_dot_clarifai_dot_api_dot_search__pb2
from clarifai.rest.grpc.proto.clarifai.api.status import status_pb2 as proto_dot_clarifai_dot_api_dot_status_dot_status__pb2
from clarifai.rest.grpc.proto.clarifai.api import subscription_pb2 as proto_dot_clarifai_dot_api_dot_subscription__pb2
from clarifai.rest.grpc.proto.clarifai.api import visualization_pb2 as proto_dot_clarifai_dot_api_dot_visualization__pb2
from clarifai.rest.grpc.proto.clarifai.api import vocab_pb2 as proto_dot_clarifai_dot_api_dot_vocab__pb2
from clarifai.rest.grpc.proto.clarifai.api import workflow_pb2 as proto_dot_clarifai_dot_api_dot_workflow__pb2


class V2Stub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Echo = channel.unary_unary(
        '/clarifai.api.V2/Echo',
        request_serializer=proto_dot_clarifai_dot_api_dot_endpoint__pb2.TestMessage.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_endpoint__pb2.TestMessage,
        )
    self.GetConceptCounts = channel.unary_unary(
        '/clarifai.api.V2/GetConceptCounts',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.GetConceptCountsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptCountResponse,
        )
    self.GetConcept = channel.unary_unary(
        '/clarifai.api.V2/GetConcept',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.GetConceptRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.SingleConceptResponse,
        )
    self.ListConcepts = channel.unary_unary(
        '/clarifai.api.V2/ListConcepts',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.ListConceptsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse,
        )
    self.PostConceptsSearches = channel.unary_unary(
        '/clarifai.api.V2/PostConceptsSearches',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.PostConceptsSearchesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse,
        )
    self.PostConcepts = channel.unary_unary(
        '/clarifai.api.V2/PostConcepts',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.PostConceptsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse,
        )
    self.PatchConcepts = channel.unary_unary(
        '/clarifai.api.V2/PatchConcepts',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.PatchConceptsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse,
        )
    self.GetVocab = channel.unary_unary(
        '/clarifai.api.V2/GetVocab',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.GetVocabRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.SingleVocabResponse,
        )
    self.ListVocabs = channel.unary_unary(
        '/clarifai.api.V2/ListVocabs',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.ListVocabsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.MultiVocabResponse,
        )
    self.PostVocabs = channel.unary_unary(
        '/clarifai.api.V2/PostVocabs',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.PostVocabsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.MultiVocabResponse,
        )
    self.PatchVocabs = channel.unary_unary(
        '/clarifai.api.V2/PatchVocabs',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.PatchVocabsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.MultiVocabResponse,
        )
    self.DeleteVocab = channel.unary_unary(
        '/clarifai.api.V2/DeleteVocab',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.DeleteVocabs = channel.unary_unary(
        '/clarifai.api.V2/DeleteVocabs',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.ListVocabConcepts = channel.unary_unary(
        '/clarifai.api.V2/ListVocabConcepts',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.ListVocabConceptsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse,
        )
    self.PostVocabConcepts = channel.unary_unary(
        '/clarifai.api.V2/PostVocabConcepts',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.PostVocabConceptsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse,
        )
    self.DeleteVocabConcept = channel.unary_unary(
        '/clarifai.api.V2/DeleteVocabConcept',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabConceptRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.DeleteVocabConcepts = channel.unary_unary(
        '/clarifai.api.V2/DeleteVocabConcepts',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabConceptsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.GetConceptLanguage = channel.unary_unary(
        '/clarifai.api.V2/GetConceptLanguage',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.GetConceptLanguageRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.SingleConceptLanguageResponse,
        )
    self.ListConceptLanguages = channel.unary_unary(
        '/clarifai.api.V2/ListConceptLanguages',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.ListConceptLanguagesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.MultiConceptLanguageResponse,
        )
    self.PostConceptLanguages = channel.unary_unary(
        '/clarifai.api.V2/PostConceptLanguages',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.PostConceptLanguagesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.MultiConceptLanguageResponse,
        )
    self.PatchConceptLanguages = channel.unary_unary(
        '/clarifai.api.V2/PatchConceptLanguages',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.PatchConceptLanguagesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.MultiConceptLanguageResponse,
        )
    self.ListConceptReferences = channel.unary_unary(
        '/clarifai.api.V2/ListConceptReferences',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__reference__pb2.ListConceptReferencesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__reference__pb2.MultiConceptReferenceResponse,
        )
    self.ListConceptRelations = channel.unary_unary(
        '/clarifai.api.V2/ListConceptRelations',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__graph__pb2.ListConceptRelationsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse,
        )
    self.GetInputCount = channel.unary_unary(
        '/clarifai.api.V2/GetInputCount',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.GetInputCountRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.SingleInputCountResponse,
        )
    self.StreamInputs = channel.unary_unary(
        '/clarifai.api.V2/StreamInputs',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.StreamInputsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse,
        )
    self.GetInput = channel.unary_unary(
        '/clarifai.api.V2/GetInput',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.GetInputRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.SingleInputResponse,
        )
    self.ListInputs = channel.unary_unary(
        '/clarifai.api.V2/ListInputs',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.ListInputsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse,
        )
    self.PostInputs = channel.unary_unary(
        '/clarifai.api.V2/PostInputs',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.PostInputsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse,
        )
    self.PatchInputs = channel.unary_unary(
        '/clarifai.api.V2/PatchInputs',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.PatchInputsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse,
        )
    self.DeleteInput = channel.unary_unary(
        '/clarifai.api.V2/DeleteInput',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.DeleteInputRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.DeleteInputs = channel.unary_unary(
        '/clarifai.api.V2/DeleteInputs',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.DeleteInputsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.PostModelOutputs = channel.unary_unary(
        '/clarifai.api.V2/PostModelOutputs',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.PostModelOutputsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_output__pb2.MultiOutputResponse,
        )
    self.PostModelFeedback = channel.unary_unary(
        '/clarifai.api.V2/PostModelFeedback',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.PostModelFeedbackRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.GetModel = channel.unary_unary(
        '/clarifai.api.V2/GetModel',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.GetModelRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse,
        )
    self.GetModelOutputInfo = channel.unary_unary(
        '/clarifai.api.V2/GetModelOutputInfo',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.GetModelRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse,
        )
    self.ListModels = channel.unary_unary(
        '/clarifai.api.V2/ListModels',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.ListModelsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.MultiModelResponse,
        )
    self.PostModelsSearches = channel.unary_unary(
        '/clarifai.api.V2/PostModelsSearches',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.PostModelsSearchesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.MultiModelResponse,
        )
    self.PostModels = channel.unary_unary(
        '/clarifai.api.V2/PostModels',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.PostModelsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse,
        )
    self.PatchModels = channel.unary_unary(
        '/clarifai.api.V2/PatchModels',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.PatchModelsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.MultiModelResponse,
        )
    self.DeleteModel = channel.unary_unary(
        '/clarifai.api.V2/DeleteModel',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.DeleteModelRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.DeleteModels = channel.unary_unary(
        '/clarifai.api.V2/DeleteModels',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.DeleteModelsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.ListModelInputs = channel.unary_unary(
        '/clarifai.api.V2/ListModelInputs',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.ListModelInputsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse,
        )
    self.GetModelVersion = channel.unary_unary(
        '/clarifai.api.V2/GetModelVersion',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.GetModelVersionRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.SingleModelVersionResponse,
        )
    self.ListModelVersions = channel.unary_unary(
        '/clarifai.api.V2/ListModelVersions',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.ListModelVersionsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.MultiModelVersionResponse,
        )
    self.PostModelVersions = channel.unary_unary(
        '/clarifai.api.V2/PostModelVersions',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.PostModelVersionsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse,
        )
    self.DeleteModelVersion = channel.unary_unary(
        '/clarifai.api.V2/DeleteModelVersion',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.DeleteModelVersionRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.GetModelVersionMetrics = channel.unary_unary(
        '/clarifai.api.V2/GetModelVersionMetrics',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.GetModelVersionMetricsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.SingleModelVersionResponse,
        )
    self.PostModelVersionMetrics = channel.unary_unary(
        '/clarifai.api.V2/PostModelVersionMetrics',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.PostModelVersionMetricsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.SingleModelVersionResponse,
        )
    self.GetWorkflow = channel.unary_unary(
        '/clarifai.api.V2/GetWorkflow',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.GetWorkflowRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.SingleWorkflowResponse,
        )
    self.ListWorkflows = channel.unary_unary(
        '/clarifai.api.V2/ListWorkflows',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.ListWorkflowsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse,
        )
    self.ListPublicWorkflows = channel.unary_unary(
        '/clarifai.api.V2/ListPublicWorkflows',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.ListPublicWorkflowsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse,
        )
    self.PostWorkflows = channel.unary_unary(
        '/clarifai.api.V2/PostWorkflows',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PostWorkflowsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse,
        )
    self.PatchWorkflows = channel.unary_unary(
        '/clarifai.api.V2/PatchWorkflows',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PatchWorkflowsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse,
        )
    self.DeleteWorkflow = channel.unary_unary(
        '/clarifai.api.V2/DeleteWorkflow',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.DeleteWorkflowRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.DeleteWorkflows = channel.unary_unary(
        '/clarifai.api.V2/DeleteWorkflows',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.DeleteWorkflowsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.PostWorkflowResults = channel.unary_unary(
        '/clarifai.api.V2/PostWorkflowResults',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PostWorkflowResultsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PostWorkflowResultsResponse,
        )
    self.PostSearches = channel.unary_unary(
        '/clarifai.api.V2/PostSearches',
        request_serializer=proto_dot_clarifai_dot_api_dot_search__pb2.PostSearchesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_search__pb2.MultiSearchResponse,
        )
    self.PostSearchFeedback = channel.unary_unary(
        '/clarifai.api.V2/PostSearchFeedback',
        request_serializer=proto_dot_clarifai_dot_api_dot_search__pb2.PostSearchFeedbackRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.GetSubscription = channel.unary_unary(
        '/clarifai.api.V2/GetSubscription',
        request_serializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.GetSubscriptionRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.SingleSubscriptionResponse,
        )
    self.PostSubscription = channel.unary_unary(
        '/clarifai.api.V2/PostSubscription',
        request_serializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.PostSubscriptionRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.SingleSubscriptionResponse,
        )
    self.GetAppVisualization = channel.unary_unary(
        '/clarifai.api.V2/GetAppVisualization',
        request_serializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.GetAppVisualizationRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.SingleVisualizationResponse,
        )
    self.GetVisualization = channel.unary_unary(
        '/clarifai.api.V2/GetVisualization',
        request_serializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.GetVisualizationRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.SingleVisualizationResponse,
        )
    self.PostVisualization = channel.unary_unary(
        '/clarifai.api.V2/PostVisualization',
        request_serializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.PostVisualizationRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.SingleVisualizationResponse,
        )
    self.ListStatusCodes = channel.unary_unary(
        '/clarifai.api.V2/ListStatusCodes',
        request_serializer=proto_dot_clarifai_dot_api_dot_code__pb2.ListStatusCodesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_code__pb2.MultiStatusCodeResponse,
        )
    self.GetStatusCode = channel.unary_unary(
        '/clarifai.api.V2/GetStatusCode',
        request_serializer=proto_dot_clarifai_dot_api_dot_code__pb2.GetStatusCodeRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_code__pb2.SingleStatusCodeResponse,
        )
    self.GetHealthz = channel.unary_unary(
        '/clarifai.api.V2/GetHealthz',
        request_serializer=proto_dot_clarifai_dot_api_dot_healthz__pb2.GetHealthzRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_healthz__pb2.GetHealthzResponse,
        )


class V2Servicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Echo(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetConceptCounts(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetConcept(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListConcepts(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostConceptsSearches(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostConcepts(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PatchConcepts(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetVocab(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListVocabs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostVocabs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PatchVocabs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteVocab(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteVocabs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListVocabConcepts(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostVocabConcepts(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteVocabConcept(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteVocabConcepts(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetConceptLanguage(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListConceptLanguages(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostConceptLanguages(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PatchConceptLanguages(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListConceptReferences(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListConceptRelations(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetInputCount(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StreamInputs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetInput(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListInputs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostInputs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PatchInputs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteInput(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteInputs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostModelOutputs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostModelFeedback(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetModel(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetModelOutputInfo(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListModels(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostModelsSearches(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostModels(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PatchModels(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteModel(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteModels(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListModelInputs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetModelVersion(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListModelVersions(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostModelVersions(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteModelVersion(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetModelVersionMetrics(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostModelVersionMetrics(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetWorkflow(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListWorkflows(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListPublicWorkflows(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostWorkflows(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PatchWorkflows(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteWorkflow(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteWorkflows(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostWorkflowResults(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostSearches(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostSearchFeedback(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetSubscription(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostSubscription(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetAppVisualization(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetVisualization(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostVisualization(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListStatusCodes(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetStatusCode(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetHealthz(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_V2Servicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Echo': grpc.unary_unary_rpc_method_handler(
          servicer.Echo,
          request_deserializer=proto_dot_clarifai_dot_api_dot_endpoint__pb2.TestMessage,
          response_serializer=proto_dot_clarifai_dot_api_dot_endpoint__pb2.TestMessage.SerializeToString,
      ),
      'GetConceptCounts': grpc.unary_unary_rpc_method_handler(
          servicer.GetConceptCounts,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.GetConceptCountsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptCountResponse.SerializeToString,
      ),
      'GetConcept': grpc.unary_unary_rpc_method_handler(
          servicer.GetConcept,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.GetConceptRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.SingleConceptResponse.SerializeToString,
      ),
      'ListConcepts': grpc.unary_unary_rpc_method_handler(
          servicer.ListConcepts,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.ListConceptsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse.SerializeToString,
      ),
      'PostConceptsSearches': grpc.unary_unary_rpc_method_handler(
          servicer.PostConceptsSearches,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.PostConceptsSearchesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse.SerializeToString,
      ),
      'PostConcepts': grpc.unary_unary_rpc_method_handler(
          servicer.PostConcepts,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.PostConceptsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse.SerializeToString,
      ),
      'PatchConcepts': grpc.unary_unary_rpc_method_handler(
          servicer.PatchConcepts,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.PatchConceptsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse.SerializeToString,
      ),
      'GetVocab': grpc.unary_unary_rpc_method_handler(
          servicer.GetVocab,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.GetVocabRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.SingleVocabResponse.SerializeToString,
      ),
      'ListVocabs': grpc.unary_unary_rpc_method_handler(
          servicer.ListVocabs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.ListVocabsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.MultiVocabResponse.SerializeToString,
      ),
      'PostVocabs': grpc.unary_unary_rpc_method_handler(
          servicer.PostVocabs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.PostVocabsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.MultiVocabResponse.SerializeToString,
      ),
      'PatchVocabs': grpc.unary_unary_rpc_method_handler(
          servicer.PatchVocabs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.PatchVocabsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.MultiVocabResponse.SerializeToString,
      ),
      'DeleteVocab': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteVocab,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'DeleteVocabs': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteVocabs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'ListVocabConcepts': grpc.unary_unary_rpc_method_handler(
          servicer.ListVocabConcepts,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.ListVocabConceptsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse.SerializeToString,
      ),
      'PostVocabConcepts': grpc.unary_unary_rpc_method_handler(
          servicer.PostVocabConcepts,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.PostVocabConceptsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse.SerializeToString,
      ),
      'DeleteVocabConcept': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteVocabConcept,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabConceptRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'DeleteVocabConcepts': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteVocabConcepts,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabConceptsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'GetConceptLanguage': grpc.unary_unary_rpc_method_handler(
          servicer.GetConceptLanguage,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.GetConceptLanguageRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.SingleConceptLanguageResponse.SerializeToString,
      ),
      'ListConceptLanguages': grpc.unary_unary_rpc_method_handler(
          servicer.ListConceptLanguages,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.ListConceptLanguagesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.MultiConceptLanguageResponse.SerializeToString,
      ),
      'PostConceptLanguages': grpc.unary_unary_rpc_method_handler(
          servicer.PostConceptLanguages,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.PostConceptLanguagesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.MultiConceptLanguageResponse.SerializeToString,
      ),
      'PatchConceptLanguages': grpc.unary_unary_rpc_method_handler(
          servicer.PatchConceptLanguages,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.PatchConceptLanguagesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.MultiConceptLanguageResponse.SerializeToString,
      ),
      'ListConceptReferences': grpc.unary_unary_rpc_method_handler(
          servicer.ListConceptReferences,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__reference__pb2.ListConceptReferencesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__reference__pb2.MultiConceptReferenceResponse.SerializeToString,
      ),
      'ListConceptRelations': grpc.unary_unary_rpc_method_handler(
          servicer.ListConceptRelations,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__graph__pb2.ListConceptRelationsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse.SerializeToString,
      ),
      'GetInputCount': grpc.unary_unary_rpc_method_handler(
          servicer.GetInputCount,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.GetInputCountRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.SingleInputCountResponse.SerializeToString,
      ),
      'StreamInputs': grpc.unary_unary_rpc_method_handler(
          servicer.StreamInputs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.StreamInputsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse.SerializeToString,
      ),
      'GetInput': grpc.unary_unary_rpc_method_handler(
          servicer.GetInput,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.GetInputRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.SingleInputResponse.SerializeToString,
      ),
      'ListInputs': grpc.unary_unary_rpc_method_handler(
          servicer.ListInputs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.ListInputsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse.SerializeToString,
      ),
      'PostInputs': grpc.unary_unary_rpc_method_handler(
          servicer.PostInputs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.PostInputsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse.SerializeToString,
      ),
      'PatchInputs': grpc.unary_unary_rpc_method_handler(
          servicer.PatchInputs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.PatchInputsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse.SerializeToString,
      ),
      'DeleteInput': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteInput,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.DeleteInputRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'DeleteInputs': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteInputs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.DeleteInputsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'PostModelOutputs': grpc.unary_unary_rpc_method_handler(
          servicer.PostModelOutputs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.PostModelOutputsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_output__pb2.MultiOutputResponse.SerializeToString,
      ),
      'PostModelFeedback': grpc.unary_unary_rpc_method_handler(
          servicer.PostModelFeedback,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.PostModelFeedbackRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'GetModel': grpc.unary_unary_rpc_method_handler(
          servicer.GetModel,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.GetModelRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse.SerializeToString,
      ),
      'GetModelOutputInfo': grpc.unary_unary_rpc_method_handler(
          servicer.GetModelOutputInfo,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.GetModelRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse.SerializeToString,
      ),
      'ListModels': grpc.unary_unary_rpc_method_handler(
          servicer.ListModels,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.ListModelsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.MultiModelResponse.SerializeToString,
      ),
      'PostModelsSearches': grpc.unary_unary_rpc_method_handler(
          servicer.PostModelsSearches,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.PostModelsSearchesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.MultiModelResponse.SerializeToString,
      ),
      'PostModels': grpc.unary_unary_rpc_method_handler(
          servicer.PostModels,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.PostModelsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse.SerializeToString,
      ),
      'PatchModels': grpc.unary_unary_rpc_method_handler(
          servicer.PatchModels,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.PatchModelsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.MultiModelResponse.SerializeToString,
      ),
      'DeleteModel': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteModel,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.DeleteModelRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'DeleteModels': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteModels,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.DeleteModelsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'ListModelInputs': grpc.unary_unary_rpc_method_handler(
          servicer.ListModelInputs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.ListModelInputsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse.SerializeToString,
      ),
      'GetModelVersion': grpc.unary_unary_rpc_method_handler(
          servicer.GetModelVersion,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.GetModelVersionRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.SingleModelVersionResponse.SerializeToString,
      ),
      'ListModelVersions': grpc.unary_unary_rpc_method_handler(
          servicer.ListModelVersions,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.ListModelVersionsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.MultiModelVersionResponse.SerializeToString,
      ),
      'PostModelVersions': grpc.unary_unary_rpc_method_handler(
          servicer.PostModelVersions,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.PostModelVersionsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse.SerializeToString,
      ),
      'DeleteModelVersion': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteModelVersion,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.DeleteModelVersionRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'GetModelVersionMetrics': grpc.unary_unary_rpc_method_handler(
          servicer.GetModelVersionMetrics,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.GetModelVersionMetricsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.SingleModelVersionResponse.SerializeToString,
      ),
      'PostModelVersionMetrics': grpc.unary_unary_rpc_method_handler(
          servicer.PostModelVersionMetrics,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.PostModelVersionMetricsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.SingleModelVersionResponse.SerializeToString,
      ),
      'GetWorkflow': grpc.unary_unary_rpc_method_handler(
          servicer.GetWorkflow,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.GetWorkflowRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.SingleWorkflowResponse.SerializeToString,
      ),
      'ListWorkflows': grpc.unary_unary_rpc_method_handler(
          servicer.ListWorkflows,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.ListWorkflowsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse.SerializeToString,
      ),
      'ListPublicWorkflows': grpc.unary_unary_rpc_method_handler(
          servicer.ListPublicWorkflows,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.ListPublicWorkflowsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse.SerializeToString,
      ),
      'PostWorkflows': grpc.unary_unary_rpc_method_handler(
          servicer.PostWorkflows,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PostWorkflowsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse.SerializeToString,
      ),
      'PatchWorkflows': grpc.unary_unary_rpc_method_handler(
          servicer.PatchWorkflows,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PatchWorkflowsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse.SerializeToString,
      ),
      'DeleteWorkflow': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteWorkflow,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.DeleteWorkflowRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'DeleteWorkflows': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteWorkflows,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.DeleteWorkflowsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'PostWorkflowResults': grpc.unary_unary_rpc_method_handler(
          servicer.PostWorkflowResults,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PostWorkflowResultsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PostWorkflowResultsResponse.SerializeToString,
      ),
      'PostSearches': grpc.unary_unary_rpc_method_handler(
          servicer.PostSearches,
          request_deserializer=proto_dot_clarifai_dot_api_dot_search__pb2.PostSearchesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_search__pb2.MultiSearchResponse.SerializeToString,
      ),
      'PostSearchFeedback': grpc.unary_unary_rpc_method_handler(
          servicer.PostSearchFeedback,
          request_deserializer=proto_dot_clarifai_dot_api_dot_search__pb2.PostSearchFeedbackRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'GetSubscription': grpc.unary_unary_rpc_method_handler(
          servicer.GetSubscription,
          request_deserializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.GetSubscriptionRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.SingleSubscriptionResponse.SerializeToString,
      ),
      'PostSubscription': grpc.unary_unary_rpc_method_handler(
          servicer.PostSubscription,
          request_deserializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.PostSubscriptionRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.SingleSubscriptionResponse.SerializeToString,
      ),
      'GetAppVisualization': grpc.unary_unary_rpc_method_handler(
          servicer.GetAppVisualization,
          request_deserializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.GetAppVisualizationRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.SingleVisualizationResponse.SerializeToString,
      ),
      'GetVisualization': grpc.unary_unary_rpc_method_handler(
          servicer.GetVisualization,
          request_deserializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.GetVisualizationRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.SingleVisualizationResponse.SerializeToString,
      ),
      'PostVisualization': grpc.unary_unary_rpc_method_handler(
          servicer.PostVisualization,
          request_deserializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.PostVisualizationRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.SingleVisualizationResponse.SerializeToString,
      ),
      'ListStatusCodes': grpc.unary_unary_rpc_method_handler(
          servicer.ListStatusCodes,
          request_deserializer=proto_dot_clarifai_dot_api_dot_code__pb2.ListStatusCodesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_code__pb2.MultiStatusCodeResponse.SerializeToString,
      ),
      'GetStatusCode': grpc.unary_unary_rpc_method_handler(
          servicer.GetStatusCode,
          request_deserializer=proto_dot_clarifai_dot_api_dot_code__pb2.GetStatusCodeRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_code__pb2.SingleStatusCodeResponse.SerializeToString,
      ),
      'GetHealthz': grpc.unary_unary_rpc_method_handler(
          servicer.GetHealthz,
          request_deserializer=proto_dot_clarifai_dot_api_dot_healthz__pb2.GetHealthzRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_healthz__pb2.GetHealthzResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'clarifai.api.V2', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
